/*
 *  swimachwinfo.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/18/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifndef __SWIMACHWINFO_H__
#define __SWIMACHWINFO_H__

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetESN - Get device's ESN
//
// Purpose:     This function returns the device's unique identity
//              as a string. The returned value is the
//              ESN (Electronic Serial Number) of the modem.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              lESN[OUT]               The destination in which the ESN
//                                      is returned.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Managing display of the ESN as a string is up to
//              you. In the CDMA marketplace, the ESN is
//              usually presented as the single 8-character string,
//              in the form of a hexadecimal number; for
//              example: CE0271C8.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetESN(SWI_U32 *lEsn, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetDeviceID - to retrieve the device ID
//
// Purpose:	This function returns the device's unique identity as a string. The 
//			returned value is the ESN (Electronic Serial Number) or EID (Electronic 
//			Identity) of the modem.
//
//			A request is sent to the modem.  The modem's response contains the
//			device ID.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			szDeviceID[OUT]:	device ID
//
//			sizeBuffer[IN]:		size of buffer provided for the device ID
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The ESN is in the form of an 14-character string of decimal numerals. 
//			The string is null terminated (adding a 15th byte to the length).
//			The content of the ESN includes several concatenated components, as 
//			specified for GPRS.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDeviceID(SWI_U8 *szDeviceID, SWI_U32 sizeBuffer, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetCarrierID - Get the Carrier ID
//
// Purpose:     This function reports the ID of the carrier the modem is 
//				configured for.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              nCarrierID[OUT]         Carrier ID.  Possible enumerated
//                                      values are defined in
//                                      SWI_TYPE_CarrierID (See
//                                      SwiStructs.h for details)
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Modems running with older firmware may not have these values
//              defined, and will return an error.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetCarrierID(SWI_TYPE_CarrierID *nCarrierID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetNetworkProviderID - to retrieve the network provider ID
//
// Purpose:	This function reports the current service provider's identification 
//			code.
//
//			A request is sent to the modem.  The modem's response contains the
//			network provider ID.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			szName[OUT]:		network provider name
//
//			sizeBuffer[IN]:		size of buffer provided for the network provider name
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The provider ID for GPRS is a string provided by the carrier, over the 
//			air. The length of the string can be up to 17 ASCII characters.  If this 
//			function is called while outside of coverage or not in service with a 
//			carrier, the function returns a null string and the OK result.  Use 
//			SwiGetServiceStatusEx to confirm coverage.  The string is null terminated.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetNetworkProviderID(SWI_U8 *szName, SWI_U32 sizeBuffer, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetIMSI - Get MIN of specified NAM
//
// Purpose:     This function returns the MIN (Mobile Identifi-cation
//              Number) string of the specified NAM
//              account profile.
//
// Parameters:  namIndex[IN]            Index (base 0) of the NAM
//                                      account to query. See
//                                      SwiGetNamInfo.
//              pszMIN[OUT]             The MIN string of the selected
//                                      NAM profile.
//              length[IN]              Size of the buffer to receive the
//                                      result.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This function returns the NMSI digits of the
//              CDMA IMSI (refer to IS-95B).
//
//              The length of the MIN string can be up to 10
//              bytes.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetIMSI(const SWI_U16 namIndex, SWI_U8 *pszMIN, SWI_U32 length, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetIMSI - Set MIN for a NAM
//
// Purpose:     This function sets the MIN string for the
//              specified NAM account profile.
//
// Parameters:  namIndex[IN]            Index (base 0) of the NAM
//                                      account to set. See
//                                      SwiGetNamInfo.
//              pszMIN[IN]              MIN to store.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The MIN is a string of the NMSI digits of the
//              CDMA IMSI (refer to IS-95B). The MIN must be
//              from 1 to 10 bytes long. The modem will pad
//              with zeroes for MINs less than 10 bytes. The
//              balance of the IMSI is pre-programmed at the
//              factory for the particular service provider.
//
//              The data is not committed until SwiPstLock is
//              called. See "Activation process" in documentation
//              for a description of the activation process.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetIMSI(const SWI_U16 namIndex, SWI_U8 *pszMIN, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetProvisioningDate - Get activation date
//
// Purpose:     This function returns the date on which a
//              specified NAM index was activated (written).
//
// Parameters:  namIndex[IN]            The (base 0) index number of the
//                                      NAM account profile to query.
//                                      See SwiGetNamInfo.
//              pszProvisioningData[OUT] Date string in the form
//                                      YYYYMMDD. An empty account
//                                      index will report all zeroes.
//              length[IN]              The maximum size of the output
//                                      string.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The provisioning date is set whenever the NAM
//              profile is written. The date comes from the
//              CDMA network at the time the account profile is
//              written, or as soon as CDMA coverage is
//              available.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetProvisioningDate(const SWI_U16 namIndex, char *szProvisioningData, SWI_U32 length, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetMobileDirNum - Get MDN of specified NAM
//
// Purpose:     This function returns the MDN (Mobile
//              Directory Number) of the specified NAM
//              account profile.
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM
//                                      account to query. See
//                                      SwiGetNamInfo.
//              MDN[OUT]                Mobile Directory Number of the
//                                      selected NAM profile.
//              length[IN]              Length of the string buffer to
//                                      receive the result.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The MDN has a maximum length of 15 bytes.
//
//              See also SwiGetPhoneNumber.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetMobileDirNum(const SWI_U16 Nam, SWI_U8 *MDN, SWI_U32 length, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetMobileDirNum - Set the Mobile Directory Number
//
// Purpose:     This function sets the MDN (Mobile Directory
//              Number) of a specified NAM account profile.
//              The modem must be unlocked via SwiPstUnlock
//              to execute this command.
//
// Parameters:  Nam[IN]                 Index (base 0) of the NAM account to set.
//              MDN[IN]                 Mobile Directory Number to store.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:       The MDN has a minimum length of 1 and a maximum length 
//              of 15 digits.
//
//              The data is not committed until SwiPstLock is
//              called. See Activation process in the API reference for
//              a description of the activation process.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetMobileDirNum(const SWI_U16 Nam, SWI_U8 *MDN, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetMEIDESN - Get device's MEID and ESN
//
// Purpose:     This function returns the device's unique identity
//              The returned value is the MEID (Mobile Equipment Identifier) and
//              ESN (Electronic Serial Number) of the modem.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pMeidEns[OUT]           The destination in which the MEID and ESN
//                                      is returned.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Managing display of the MEID and ESN is up to you.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetMEIDESN(SWI_STRUCT_MeidEsn *pMeidEsn, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        VerifyUpgradeRequired
//
// Purpose:     Verify if modem upgrade is required
//
// Parameters:  szUpgradePath[IN]       Path for CCT files.
//              peRCode[OUT]			Return code for this operation
//				szFileName[OUT]			Full file name for CCT executable file
//              pnLength[IN, OUT]		Size for szFileName buffer.
//                                      return needed size for szFileName buffer 
//                                      in case return code is SWI_Small_File_Name_Buffer.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiVerifyUpgradeRequired(SWI_U8 *szUpgradePath, SWI_TYPE_MdmUpgradeCheck *peRCode,SWI_U8 *szFileName, SWI_U16 *pnLength, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPRLVersion - Get PRL version
//
// Purpose:     
//
// Parameters:  szLength[IN]            The maximum size of the output
//                                      string (szDriverVersion).
//              timeout[IN]             Function timeout in milliseconds
//              pPrlVersion[OUT]        Version number of the current
//                                      PRL.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPRLVersion(SWI_U16 *pPrlVersion, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetNamInfo - Get NAM profile info
//
// Purpose:     This function reports information about the
//              modemís NAM profile table: the number of
//              profiles supported, and the next empty table
//              entry.
//
// Parameters:  cntNamProfile[OUT]      The total number of NAM profiles
//                                      the modem can support.
//              nextNamProfile[OUT]     The index number (base 0) of the
//                                      next empty profile. 0xFFFF
//                                      indicates no empty profiles.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       See "Activation process" in documentation.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetNamInfo(SWI_U16 *cntNamProfile, SWI_U16 *nextNamProfile, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetMipErrCode - Get last Mobile IP registration error
//
// Purpose:     This function returns the last Mobile IP registration error
//              received from the network.  See also SwiGetMipErrCodeEx().
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              nErrCode[OUT]           The destination in which the error
//                                      code is returned.  See Notes below
//                                      for possible values.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       See SwiGetMipErrCodeEx for details.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetMipErrCode(SWI_U16 *nErrCode, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetMipErrCodeEx - Get last Mobile IP registration error
//
// Purpose:     This function returns the last Mobile IP registration error
//              received from the network.  This function extends SwiGetMipErrCode
//              by adding support for carrier-defined errors (nErrCode2).
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              nErrCode[OUT]           The destination in which the error
//                                      code is returned.  See Notes below
//                                      for possible values.
//              nErrcode2[OUT]          Carrier specific error code.  Valid
//                                      only when nErrCode = 89.  See notes
//                                      below for possible values.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This function should be called when 
//
//              The standard error code definitions can be found in the following
//              public references:
//                                      Mobile IP RFC2002
//              
//              The classification of the error codes used by Watcher are as
//              follows:
//
//              - No Error
//                                      0, 1, 0xffff
//              - Registration failure
//                                      67
//              - Sign-in failure
//                                      131, 133
//              - Session request too long
//                                      69
//              - Home Agent failure
//                                      80, 81, 82, 88
//              - Unknown Error
//                                      64, 65, 128, 129
//              - Unrecognizable Home Agent Addresses
//                                      136
//              - Network Error
//                                      66, 68, 97-101, 130, 132, 140, 141
//              - System Error
//                                      70-76, 79, 96, 104-106, 134, 135, 137-139
//              - Cannot prepare data services
//                                      1012
//              - Suspension of Account
//                                      801
//              - Carrier Specific
//                                      89
//
//              Carrier specific error codes (valid when nErrCode = 89) include 
//              the following:
//
//              Verizon:
//              1 - General Failure
//              2 - Authentication Failure
//              3 - Invalid Service Failure
//              4 - Invalid Public Key Failure
//
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetMipErrCodeEx(SWI_U16 *nErrCode1, SWI_U16 *nErrCode2, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetHdrSrvState - Get HDR Service State
//
// Purpose:     This function gets the HDR service state.
//
// Parameters:  iHdrSrvState[OUT]	  HDR service state.
//                                  0 = No Service
//                                  2 = HDR Service
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetHdrSrvState(SWI_U16 *iHdrSrvState, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetHdrHybrPref - Get HDR Hybrid Pref
//
// Purpose:     This function gets the HDR Hybrid Pref setting.
//
// Parameters:  iHdrHybrPref[OUT]	  HDR Hybrid Pref setting
//                                  0 = OFF
//                                  1 = ON
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetHdrHybrPref(SWI_U16 *iHdrHybrPref, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetHdrHybrPref - Set HDR Hybrid Pref
//
// Purpose:     This function sets the HDR Hybrid Pref setting.
//
// Parameters:  iHdrHybrPref[IN]	  HDR Hybrid Pref setting
//                                  0 = OFF
//                                  1 = ON
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetHdrHybrPref(SWI_U16 iHdrHybrPref, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetNDISMode - Retrieve NDIS mode supported in the modem 
//
// Purpose:     This function gets the current state of the NDIS mode supported in
//				the modem.
//
// Parameters:  NDISMuxMode, pointer to SWI_NDIS_MUX_MODE structure.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:		This function is only supported for products that use the USB MUX 
//				driver architecture. Always return false on Mac.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetNDISMode(SWI_NDIS_MUX_MODE *NDISMuxMode);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetNDISPrefMode - Set NDIS Pref mode 
//
// Purpose:     This function sets the current state of the NDIS mode supported.
//
// Parameters:  eNDISPrefMode, the mode requested.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:		Not supported on Mac.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetNDISPrefMode(SWI_NDIS_PREF_MODE eNDISPrefMode);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetAutoconnect - Get Autoconnect flag status from modem
//
// Purpose:     This function will be used to get auto connect flag ( for data call)set in modem 
//				
// Parameters:  
//            nEnable[OUT]        value 1 = enable ; 0 to disable
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:			
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetAutoconnect(SWI_U16 *pnEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetAutoconnect - Get Autoconnect flag.
//
// Purpose:     This function will be used to set auto connect flag ( for data call).
//				
// Parameters:  
//            nEnable[IN]        value 1 = enable ; 0 to disable
//            timeout[IN]         Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
// Notes:			
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetAutoconnect(const SWI_U16 nEnable, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetSecureChallenge
//
// Purpose:     Send the secure challenge during manual activation sequence
//
// Parameters:  pszSCD[IN]				Secure Challenge Digits (SCD)
//				pszSCR[OUT]				Secure Challenge Response (SCR)
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSecureChallenge(SWI_U8 *pszSCD, SWI_U8 *pszSCR, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetSecureRebuttal
//
// Purpose:     Send the secure challenge rebuttal during manual activation sequence
//
// Parameters:  pszSRD[IN]				Secure Rebuttal Digits (SRD)
//				pSRR[OUT]				Secure Rebuttal Response (SRR)
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSecureRebuttal(SWI_U8 *pszSRD, SWI_U16 *pSRR, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetSecureCommitUpdate
//
// Purpose:     Terminate and commit the activation sequence
//
// Parameters:  commitType[IN]			Commit type
//              namIndex[IN]			NAM index
//				commitResult[OUT]		Commit result
//				failureMask[OUT]		Failure mask (provisioning)
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSecureCommitUpdate(const SWI_TYPE_CommitType commitType, 
														const SWI_U16 namIndex,
														SWI_TYPE_CommitResult *commitResult, 
														SWI_TYPE_CommitResultMask *failureMask,
														SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:		SwiSetTempModePref - Set modem preference
//
// Purpose:		This function sets modem preference
//
// Parameters:	nModePref[IN]			Modem preference
//				nModeTerm[IN]			Mode preference change termination
//				nModeDur[IN]			Time in secs for temporary mode preference change
//				nBandPref[IN]			Band preference to switch to
//				nRoamPref[IN]			Roam preference to switch to
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:		None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetTempModePref(SWI_U16 nModePref, SWI_U16 nModeTerm, SWI_U32 nModeDur, SWI_U32 nBandPref, SWI_U16 nRoamPref, SWI_U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWSetPower - Change the HW Power State of the modem
//
// Purpose:     This function changes the Hard Power State of the modem to:  
//					Hard On
//					Hard Off
//				This function can be called outside of the SwiApiOpenEx context
//				This function delegates to the BIOS to service the request. No 
//					state machine management!!!
//
// Parameters:  hwPowerState, one of the SWIHW_TYPE_Power.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       After the reset, any previously enabled notifications must be 
//				re-enabled, and any previous modem states and/or information 
//				may no longer be valid.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiHWSetPower(SWIHW_TYPE_Power hwPowerState);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWGetPower - Retrieve the HW Power State of the modem
//
// Purpose:     This function can be called outside of the SwiApiOpenEx context
//				This function delegates to the BIOS to service the request. No 
//					state machine management!!!
//
// Parameters:  hwPowerStateP, one of the SWIHW_TYPE_Power.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiHWGetPower(SWIHW_TYPE_Power *hwPowerStateP);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWInitialize - Initialize the HW Power State machine
//
// Purpose:     This function can be called outside of the SwiApiOpenEx context
//				This function prepares the HW power state machine to talk to BIOS
//        for power state machine management!!!
//
// Parameters:  None
//
// Return:      No special handling.
//              See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiHWInitialize();

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWUnInitialize - UnInitialize the HW Power State machine
//
// Purpose:     This function can be called outside of the SwiApiOpenEx context
//				This function shuts down the HW power state machine that talks to BIOS
//        for power state machine management!!!
//
// Parameters:  None
//
// Return:      void
//
//////////////////////////////////////////////////////////////////////////////////
void SwiHWUnInitialize();


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWGetOEMIDStrA - Retrieve the HW OEM ID string
//
// Purpose:     This function can be called outside of the SwiApiOpenEx context
//				This function delegates to the BIOS to service the request. No 
//					state machine management!!!
//
// Parameters:  szOEMIDStr[out], the OEM ID string.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiHWGetOEMIDStrA(SWI_U8 szOEMIDStr[256]);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiHWRegisterCallback - Register the callback function for HW power
//											state change.
//
// Purpose:     This function can be called outside of the SwiApiOpenEx context
//				The callback pointer can be unregistered with NULL pointer
//				or unloading the dll
//
// Parameters:  pCallBack, pointer to the callback function.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiHWRegisterCallback(SWI_CALLBACK_EX pCallBack);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetPower - Change the SW Power State of the modem
//
// Purpose:     This function changes the Soft Power State of the modem to:  
//					Offline
//					RF Power On/Off
//					Reset
//				This function can be called only within the SwiApiOpenEx context
//				This function delegates to the modem to service the request. No 
//				state machine management!!!
//
// Parameters:  fwPowerState[IN]:	one of the SWI_TYPE_Power.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       After the reset, any previously enabled notifications must be 
//				re-enabled, and any previous modem states and/or information 
//				may no longer be valid.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetPower(SWI_TYPE_Power fwPowerState);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPower - Retrieve the SW Power State of the modem
//
// Purpose:     This function can be called only within the SwiApiOpenEx context
//				This function delegates to the modem to service the request. No 
//				state machine management!!!
//
// Parameters:  pfwPowerState[IN]:	one of the SWI_TYPE_Power.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPower(SWI_TYPE_Power *pfwPowerState);



//////////////////////////////////////////////////////////////////////////////////
//
// Voice and audio functions
//
// The following group of functions are used
// controlling audio features, generally used for
// voice calls. Also covered are functions related to
// DTMF tones.
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetSpeakerVolume - Get the headset volume
//
// Purpose:     This function reports the volume level of the
//              speaker (headset output).
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pSpeakerVolume[OUT]     The destination in which the
//                                      volume level is returned:
//                                      0 = muted (see remarks)
//                                      1 = quietest
//                                      6 = loudest
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The level can be set using SwiSetSpeakerVolume.  The level 
//              setting is retained across resets and power cycles.
//
//              There is a separate speaker mute setting
//              (SwiGetSpeakerMuteStatus) that does not alter the level reported 
//              here. If the volume level reported is 0, the speaker is muted 
//              regardless of the setting of the mute state. If the mute is on,
//              the speaker level reported here is the normal
//              setting that will be used when mute is switched off.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSpeakerVolume(SWI_U16 *pSpeakerVolume, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetSpeakerVolume - Set the headset volume
//
// Purpose:     This function sets the volume level of the speaker
//              (headset output).
//
// Parameters:  SpeakerVolume[IN]       The volume level to set:
//                                      0 = mute (see remarks)
//                                      1 = quietest
//                                      6 = loudest
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The level setting is retained across resets and power cycles.
//
//              A normal practice is to step the volume up or down, one step at 
//              a time. The current level setting can be read using 
//              SwiGetSpeakerVolume.
//
//              There is a separate speaker mute setting (SwiSetSpeakerMuteStatus) 
//              that does not alter the level set here. Use the mute state to 
//              switch the speaker on and off without altering the normal
//              listening level.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSpeakerVolume(const SWI_U16 SpeakerVolume, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetSpeakerMuteStatus - Get the headset volume mute status
//
// Purpose:     This function reports the status of the speaker mute setting.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pSpeakerMuteStatus[OUT] The destination in which the 
//                                      mute state is returned:
//                                      0 = speaker on
//                                      1 = muted (speaker off)
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This mute status is distinct from a volume level of zero (muted). 
//              The volume level set with SwiSetSpeakerVolume is retained 
//              regardless of the setting of the mute status.
//
//              The mute state is controlled with SwiSetSpeakerMuteStatus.
//
//              The mute setting is disabled (speaker on) when a call is 
//              disconnected.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSpeakerMuteStatus(SWI_U16 *pSpeakerMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetSpeakerMuteStatus - Mute the headset volume
//
// Purpose:     This function sets the mute status of the speaker
//              (headset output).
//
// Parameters:  SpeakerMuteStatus[IN]   The mute state to set:
//                                      0 = speaker on
//                                      1 = mute (speaker off)
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This mute status is distinct from a volume level of zero (muted). 
//              The volume level set with SwiSetSpeakerVolume is retained 
//              regardless of the setting of the mute status.
//
//              The mute state can be read with SwiGetSpeakerMuteStatus.
//
//              The mute setting is automatically disabled
//              (speaker enabled) when a call is disconnected.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSpeakerMuteStatus(const SWI_U16 SpeakerMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetHeadsetState - Determine if headset is plugged in
//
// Purpose:     This function reports whether or not the headset is attached.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              headsetState[OUT]       The destination in which the state
//                                      is returned:
//                                      0 = unplugged (removed)
//                                      1 = attached (inserted)
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Headset state is not supported on the SB555.
//
//              A polling version of this command is available
//              using SWI_NOTIFY_HeadsetState.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetHeadsetState(SWI_U16 *headsetState, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetToneLevel - Get the DTMF volume
//
// Purpose:     This function reports the volume level of DTMF
//              tones sent to the speaker (headset output).
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pToneLevel[OUT]         The destination in which the tone
//                                      level is returned:
//                                      0 = muted (see remarks)
//                                      1 = quietest
//                                      6 = loudest
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The level can be set using SwiSetToneLevel. The
//              level setting is retained across resets and power cycles.
//
//              There are separate tone (SwiGetDTMFMuteStatus) and speaker 
//              (SwiGetSpeakerMuteStatus) mute settings that do not alter the 
//              level reported here.
//
//              If the speaker mute is on, DTMF tones are not
//              heard regardless of the tone level or DTMF mute status.
//
//              If the tone level reported is 0, no DTMF tones are heard on the 
//              speaker regardless of the settings of the mute states.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetToneLevel(SWI_U16 *pToneLevel, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetToneLevel - Set the DTMF volume
//
// Purpose:     This function sets the volume level of DTMF
//              tones sent to the speaker (headset output).
//
// Parameters:  ToneLevel[IN]           The volume level to set:
//                                      0 = mute (see remarks)
//                                      1 = quietest
//                                      6 = loudest
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The level setting is retained across resets and power cycles.
//
//              A normal practice is to step the volume up or down, one step 
//              at a time. The current tone level setting can be read using 
//              SwiGetToneLevel.
//              There are separate tone (SwiSetDTMFMuteStatus) and speaker 
//              (SwiGetSpeakerMuteStatus) mute settings that do not alter 
//              the level reported here.
//
//              If the speaker mute is on, DTMF tones are not heard 
//              regardless of the tone level or DTMF mute status.
//
//              Use the DTMF mute state to enable or disable
//              DTMF tones on the speaker.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetToneLevel(SWI_U16 ToneLevel, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDTMFMuteStatus - Get the status of the DTMF mute option
//
// Purpose:     This function reports the status of the DTMF tone mute setting.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pDTMFMuteStatus[OUT]    The destination in which the
//                                      mute state is returned:
//                                      0 = DTMF level enabled
//                                      1 = muted
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This mute status is distinct from both the tone level of zero 
//              (muted), and the state of the speaker mute. The volume level 
//              set with SwiSetToneLevel is retained regardless of the
//              setting of the mute status.
//
//              The mute state is controlled with SwiSetDTMFMuteStatus. 
//              When muted, tones are not sent to the speaker. When not muted, 
//              tones may still not be heard if the speaker mute is on.
//
//              The mute setting is not retained across resets and
//              power cycles. The modem does retain the setting
//              of DTMF mute during the session (across multiple calls).    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDTMFMuteStatus(SWI_U16 *pDTMFMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetDTMFMuteStatus - Mute the DTMF tones
//
// Purpose:     This function sets the mute status of DTMF tones
//
// Parameters:  DTMFMuteStatus[IN]      The mute state to set:
//                                      0 = DTMF level enabled
//                                      1 = muted
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       This mute status is distinct from a volume level
//              of zero (muted). The volume level set with
//              SwiSetToneLevel is retained regardless of the
//              setting of the mute status.
//
//              The mute state can be read with SwiGetDTMFMuteStatus.
//
//              The mute setting is not retained across resets and
//              power cycles. The modem does retain the setting
//              of DTMF mute during the session (across multiple calls).    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetDTMFMuteStatus(SWI_U16 DTMFMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetMICMuteStatus - Get the mute status of the microphone
//
// Purpose:     This function reports the status of the microphone
//              (headset input) mute setting.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pMICMuteStatus[OUT]     The destination in which the
//                                      mute state is returned:
//                                      0 = MIC enabled
//                                      1 = muted
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The mute state is controlled with SwiSetMICMuteStatus.
//
//              The mute setting is automatically disabled (MIC
//              enabled) when a call is disconnected.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetMICMuteStatus(SWI_U16 *pMICMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetMICMuteStatus - Mute the microphone
//
// Purpose:     This function sets the mute status of the microphone
//              (headset input).
//
// Parameters:  MICMuteStatus[IN]       The mute state to set:
//                                      0 = MIC enabled
//                                      1 = muted
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The mute state can be read with SwiGetMICMuteStatus.
//
//              The mute setting is automatically disabled (MIC
//              enabled) when a call is disconnected.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetMICMuteStatus(const SWI_U16 MICMuteStatus, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetDTMFKey - Generate a DTMF tone
//
// Purpose:     This function generates a single DTMF key tone.
//
// Parameters:  DTMFKey[IN]             The enumerated type for the key
//                                      tone to generate.
//                                      NOTE: Only the first 12 entries in
//                                      the data type are valid for this
//                                      function: #, *, 0-9.
//              timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The duration of the tone is determined by SwiSetDTMFDuration.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetDTMFKey(const SWI_TYPE_PhoneKey DTMFKey, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetDTMFDuration - Get the DTMF tone length
//
// Purpose:     This function reports the settings for the duration
//              of DTMF tone generation for both single key 
//              events and multi-key strings.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              pDTMFKeyOn[OUT]         On duration for single key events.
//                                      100-3000 ms.
//              pDTMFBurstDigitOn[OUT[  On duration for multi-key strings.
//                                      95-350 ms.
//              pDTMFBurstInterdigitOff[OUT] 
//                                      Off duration between keys in
//                                      multi-key strings.
//                                      60-200 ms.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The values for tone durations are set with SwiSetDTMFDuration.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetDTMFDuration(SWI_U16 *pDTMFKeyOn, SWI_U16 *pDTMFBurstDigitOn, 
                                        SWI_U16 *pDTMFBurstInterdigitOff, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetDTMFDuration - Set the DTMF tone length
//
// Purpose:     This function sets the durations for DTMF tone generation.
//
// Parameters:  DTMFKeyOn[IN]           On duration for single key events.
//              DTMFBurstDigitOn[IN]    On duration for single key events.
//                                      100-3000 ms.
//              DTMFBurstInterdigitOff[IN] 
//                                      On duration for multi-key strings.
//                                      95-350 ms.
//              timeout[IN]             Off duration between keys in 
//                                      multi-key strings.
//                                      60-200 ms.
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The settings can be read using SwiGetDTMFDuration.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetDTMFDuration(const SWI_U16 DTMFKeyOn, const SWI_U16 DTMFBurstDigitOn,
									const SWI_U16 DTMFBurstInterdigitOff, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetKeyPressed - Generate a DTMF tone over headset
//
// Purpose:     This function causes the modem to play audible
//              DTMF key tones to the speaker (headset output).
//
// Parameters:  phoneKey[IN]            The enumerated type for the key
//                                      tone to generate. See documentation.
//                                      NOTE: Only the first 12 entries in
//                                      the data type are valid for this
//                                      function: #, *, 0-9.
//				timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       The tone is sent to the headset but not over the
//              air. This is a human feedback for button pressing
//              on a software keypad. The tone continues to
//              sound until SwiSetKeyReleased is called.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetKeyPressed(const SWI_TYPE_PhoneKey phoneKey, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiSetKeyReleased - Stop playing a DTMF over headset
//
// Purpose:     This function stops a DTMF key tone playback in
//              the headset that was initiated with SwiSetKeyPressed.
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetKeyReleased(SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
//	Name:		SwiGetPRIVersion - Retrieve the modem PRI version
//
//	Purpose:	This function retrieves the modem's PRI version.
//
//	Parameters:	pMajor[Out]				PRI major version
//				pMinor[Out]				PRI minor version
//
//
//	Return:		SWI_RCODE_OK            The function executed normally. 
//				SWI_RCODE_FAILED        The operation failed in the modem. 
//				SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
//	Note:		Sometimes these values are returned "swapped". This is a firmware
//				issue. Use these values for display only.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPRIVersion(SWI_U8 *pMajor, SWI_U8 *pMinor, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiGetPRISKU - Retrieve the modem PRISKU version
//
// Purpose:     This function retrieves the modem's PRI version.
//
// Parameters:  pPRISKU[Out]			PRISKU
//              
//              
// Return:      SWI_RCODE_OK            The function executed normally. 
//              SWI_RCODE_FAILED        The operation failed in the modem. 
//              SWI_RCODE_REQUEST_TIMEOUT 
//                                      The function failed to complete within 
//                                      the timeout.  
// Notes:       None.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPRISKU(SWI_U32 *priSKU, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:		SwiGetPriChksum - Get PRI Checksum
//
// Purpose:		This function is used to get the PRI Checksum
//				
// Parameters:	priChksum[OUT]		Pointer to data buffer
//				timeout[IN]			Function timeout in milliseconds
//
// Return:      See SwiRcodes.h
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetPriChksum(SWI_U16* priChksum, SWI_U32 timeout);

//**********************************************************************************
//	SwiGetHardwareData
//		This call returns all the Hardware data in one structure
//		the primary use is to check all the "GET" calls for
//		Hardware
//**********************************************************************************
#define HW_DEVICE_ID_LENGTH 20
#define HW_ISP_LENGTH 20
#define HW_MIN_LENGTH 11
#define HW_MDN_LENGTH 16

typedef struct allHardwareData
{
	SWI_RCODE			_ret[25];
	SWI_U32				_esn;
	SWI_U8				_deviceID[HW_DEVICE_ID_LENGTH];
	SWI_TYPE_CarrierID	_carrierID;
	SWI_U8				_providerID[HW_ISP_LENGTH];
	SWI_U8				_min0[HW_MIN_LENGTH];
	SWI_U8				_mdn0[HW_MDN_LENGTH];
	SWI_STRUCT_MeidEsn	_meidEsn;
	SWI_U16				_prlVersion;
	SWI_U16				_maxProfiles;
	SWI_U16				_nextProfile;
	SWI_U16				_mipErrorCode;
	SWI_U16				_extendedMipErrorCode1;
	SWI_U16				_extendedMipErrorCode2;
	SWI_U16				_hdrServiceState;
	SWI_U16				_hdrHybridPref;
	SWI_NDIS_MUX_MODE	_ndisMuxMode;
	SWI_U16				_autoConnectEnabled;
	SWI_TYPE_Power		_power;
	SWI_U16				_speakerVolume;
	SWI_U16				_speakerMuted;
	SWI_U16				_headsetAttached;
	SWI_U16				_toneLevel;
	SWI_U16				_dtmfMuted;
	SWI_U16				_micMuted;
	SWI_U16				_dtmfOnDuration;
	SWI_U16				_dtmfBurstOnDuration;
	SWI_U16				_dtmfBurstOffDuration;
	SWIHW_TYPE_Power	_hardwarePowerState;
	SWI_U8				_hardwareOEMString[256];
} allHardwareData;

SWI_RCODE SwiGetHardwareData(allHardwareData *data);


#ifdef __cplusplus
}
#endif

#endif // __SWIMACHWINFO_H__
