/*
 *  swimacsms.h
 *  swimac
 *
 *  Created by Jerry Pickering on 1/17/08.
 *  Copyright 2008 Sierra Wireless, Inc. All rights reserved.
 *
 */

#ifdef __cplusplus
extern "C"	{
#endif

#import "swimacrcodes.h"
#import "swimacdatatypes.h"
#import "swimacstructs.h"

//////////////////////////////////////////////////////////////////////////////////
//
// SMS structures
//
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PRI_SmsMask - SMS Support mask bit enumeration
//
// Purpose:     The enumerated mask bits identifies the SMS features
//				supported by the modem
//
// Members:  	SWI_PRI_SMS_MT				- Mobile Terminated (Incoming) SMS supported
//				SWI_PRI_SMS_MO				- Mobile Originated (Outgoing) SMS supported
//				SWI_PRI_SMS_ALL				- Internal Use
//				SWI_PRI_SMS_MASK_ENABLED	- Internal use
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PRI_SmsMask
{
	SWI_PRI_SMS_MT						= 0x0001,	
	SWI_PRI_SMS_MO						= 0x0002,	
	SWI_PRI_SMS_ALL						= 0xFFFF,

	SWI_PRI_SMS_MASK_ENABLED			= 0x8000	// Enabled bit (Internal use only)
};

//////////////////////////////////////////////////////////////////////////////////
//
// SMS functions
//
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SwiPriGetSMSMask - Get modem's SMS capabilities
//
// Purpose:     This function reports the modem's SMS capabilities
//
// Parameters:  timeout[IN]             Function timeout in milliseconds
//              smsMask[OUT]            The destination in which the
//                                      the data is returned. Possible mask
//                                      bit values are defined in
//                                      SWI_TYPE_PRI_SmsMask (See
//                                      SwiStructs.h for details)
//
// Return:      No special handling.
//              See SwiRcodes.h
//
// Notes:       Modems running with older firmware may not have these values
//              defined, and will return an error.    
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiPriGetSMSMask(SWI_U16* smsMask, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetSMSMessageStatus - to query the outstanding SMS message status
//
// Purpose:	This function is used to query the outstanding SMS message status.
//
//			A request is sent to the modem.  The modem's response contains the
//			outstanding SMS message status.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			SMS_Status[OUT]:	outstanding SMS message status
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSMSMessageStatus(SWI_STRUCT_SMS_Status *SMS_Status, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiRetrieveSMSMessage - to retrieve an SMS message and delete it
//
// Purpose:	This function is used to retrieve an SMS message, and to delete
//          it from modem RAM.
//
//			A request is sent to the modem.  The modem's response contains the
//			SMS message.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			pSMS[OUT]:			SMS message
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	This function should be called repeatedly to read all messages
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiRetrieveSMSMessage(SWI_STRUCT_SMS_RetrieveSms *pSMS, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiRetrieveSMSMessageEx - to retrieve an SMS message with option to delete it 
//                                  or not
//
// Purpose:	This function is used to retrieve an SMS message, with addition
//          of flag to specify if the message is to be deleted from modem RAM
//          or not.
//
//			A request is sent to the modem.  The modem's response contains the
//			SMS message.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			pSMS[OUT]:			SMS message
//
//      bDeleteAfterRetrieve[IN] : TRUE to delete the message after retrieval from modem
//                                  FALSE to leave it in the modem store
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	This function should be called repeatedly to read all messages
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiRetrieveSMSMessageEx(SWI_STRUCT_SMS_RetrieveSms *pSMS, bool bDeleteAfterRetrieve, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMessageRetrieved - to set a message as retrieved so modem can delete it 
//
// Purpose:	This function is used to set a message as retrieved
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			msgID[IN]:			SMS message ID to be deleted
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetMessageRetrieved(const SWI_U16 msgID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiDeleteSMS - to delete an SMS message from the card
//
// Purpose:	This function is used to delete an SMS message from the card.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request has been processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			msgID[OUT]:			message ID
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The user must request a message to be deleted.  This function should never
//			be used to automatically delete an SMS message.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiDeleteSMS(const SWI_U16 msgID, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetSmsParam - to get SMS parameters
//
// Purpose:	This function is used to get SMS parameters.
//
//			A request is sent to the modem.  The modem's response contains the
//			SMS parameters.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			SmsParam[OUT]:		SMS parameters
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiGetSmsParam(SWI_STRUCT_SMS_Param *SmsParam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetSmsParam - to set SMS parameters
//
// Purpose:	This function is used to set SMS parameters.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request has been processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			SmsParam[OUT]:		SMS parameters
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSetSmsParam(const SWI_STRUCT_SMS_Param *SmsParam, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiStoreSMSMessage - to store an SMS message
//
// Purpose:	This function is used to store an SMS message.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request has been processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			StoreSMS[OUT]:		SMS message to store
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	This function could be called repeatedly to send a series of SMS messages
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiStoreSMSMessage(SWI_STRUCT_SMS_StoreSms *StoreSMS, SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSendSMS - to start sending stored SMS messages
//
// Purpose:	This function is used to start sending stored SMS messages.  The messages
//			sent were previously stored by the SwiStoreSMSMessage function.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiSendSMS(SWI_U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiClearVoicemail - to delete voicemail SMS on the modem
//
// Purpose:	This function is used to delete voicemail SMS on the modem.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_RCODE SwiClearVoicemail(SWI_U32 timeout);


//**********************************************************************************
//	SwiGetSMSData - 
//		This call returns all the SMS data in one structure
//		the primary use is to check all the "GET" calls for
//		SMS
//**********************************************************************************
typedef struct allSMSData
{
	SWI_RCODE				_ret[2];
	SWI_STRUCT_SMS_Status	_smsStatus;
	SWI_STRUCT_SMS_Param	_smsParam;
} allSMSData;

SWI_RCODE SwiGetSMSData(allSMSData *data);

#ifdef __cplusplus
}
#endif
